@@ -1,21 +1,8 @@
 /*
-  Copyright (c) 2010 Bertjan Broeksema <broeksema@kde.org>
-  Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileCopyrightText: 2010 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "incidenceattachment.h"
@@ -35,7 +22,6 @@
 #include <QMenu>
 #include <KMessageBox>
 #include <KProtocolManager>
-#include <kio_version.h>
 #include <KIO/JobUiDelegate>
 #include <KIO/OpenUrlJob>
 #include <KIO/Job>
@@ -92,7 +78,7 @@ void IncidenceAttachment::save(const KCalendarCore::Incidence::Ptr &incidence)
 
     for (int itemIndex = 0; itemIndex < mAttachmentView->count(); ++itemIndex) {
         QListWidgetItem *item = mAttachmentView->item(itemIndex);
-        AttachmentIconItem *attitem = dynamic_cast<AttachmentIconItem *>(item);
+        auto *attitem = dynamic_cast<AttachmentIconItem *>(item);
         Q_ASSERT(item);
         incidence->addAttachment(attitem->attachment());
     }
@@ -183,11 +169,13 @@ void IncidenceAttachment::removeSelectedAttachments()
 {
     QList<QListWidgetItem *> selected;
     QStringList labels;
+    selected.reserve(mAttachmentView->count());
+    labels.reserve(mAttachmentView->count());
 
     for (int itemIndex = 0; itemIndex < mAttachmentView->count(); ++itemIndex) {
         QListWidgetItem *it = mAttachmentView->item(itemIndex);
         if (it->isSelected()) {
-            AttachmentIconItem *attitem = static_cast<AttachmentIconItem *>(it);
+            auto *attitem = static_cast<AttachmentIconItem *>(it);
             if (attitem) {
                 const KCalendarCore::Attachment att = attitem->attachment();
                 labels << att.label();
@@ -235,7 +223,7 @@ void IncidenceAttachment::saveAttachment(QListWidgetItem *item)
     Q_ASSERT(item);
     Q_ASSERT(dynamic_cast<AttachmentIconItem *>(item));
 
-    AttachmentIconItem *attitem = static_cast<AttachmentIconItem *>(item);
+    auto *attitem = static_cast<AttachmentIconItem *>(item);
     if (attitem->attachment().isEmpty()) {
         return;
     }
@@ -277,7 +265,7 @@ void IncidenceAttachment::showAttachment(QListWidgetItem *item)
 {
     Q_ASSERT(item);
     Q_ASSERT(dynamic_cast<AttachmentIconItem *>(item));
-    AttachmentIconItem *attitem = static_cast<AttachmentIconItem *>(item);
+    auto *attitem = static_cast<AttachmentIconItem *>(item);
     if (attitem->attachment().isEmpty()) {
         return;
     }
@@ -289,12 +277,11 @@ void IncidenceAttachment::showAttachment(QListWidgetItem *item)
         KIO::OpenUrlJob *job = new KIO::OpenUrlJob(attitem->tempFileForAttachment(), att.mimeType());
         job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, mAttachmentView));
         job->setDeleteTemporaryFile(true);
-        job->setRunExecutables(true);
         job->start();
     }
 }
 
-void IncidenceAttachment::showContextMenu(const QPoint &pos)
+void IncidenceAttachment::showContextMenu(const QPoint &pos)    // clazy:exclude=function-args-by-value
 {
     const bool enable = mAttachmentView->itemAt(pos) != nullptr;
 
@@ -343,7 +330,7 @@ void IncidenceAttachment::editSelectedAttachments()
         if (item->isSelected()) {
             Q_ASSERT(dynamic_cast<AttachmentIconItem *>(item));
 
-            AttachmentIconItem *attitem = static_cast<AttachmentIconItem *>(item);
+            auto *attitem = static_cast<AttachmentIconItem *>(item);
             if (attitem->attachment().isEmpty()) {
                 return;
             }
@@ -565,7 +552,7 @@ void IncidenceAttachment::setupAttachmentIconView()
     connect(mAttachmentView, &AttachmentIconView::customContextMenuRequested, this,
             &IncidenceAttachment::showContextMenu);
 
-    QGridLayout *layout = new QGridLayout(mUi->mAttachmentViewPlaceHolder);
+    auto *layout = new QGridLayout(mUi->mAttachmentViewPlaceHolder);
     layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(mAttachmentView);
 }
